clear all;
format short eng;

%% parameters

Prated=200*746; % rated output
Vs_LtoL_rated=380; % rated value of line to line voltage
Vs_rated=Vs_LtoL_rated/sqrt(3); % rated value of phase voltage
Is_rated=240; % rated value of phase current
p=4; % number of poles
Wr_rated=60*2*pi;
Xs=0.6;
Ls=Xs/Wr_rated;
Ra=0.02;


%% Calculating Lambda_f and Base Speed

syms Lambda_f
Pin=Prated+3*Is_rated^2*Ra;
Is_real=Pin/Vs_rated/3;
Is_imag=sqrt(Is_rated^2-Is_real^2);
Is=Is_real-j*Is_imag;
E=Vs_rated-(Ra+j*Xs)*Is;
Lambda_f=abs(E)/Wr_rated;

syms W1 W2
f2=(Ls*W1*Is_rated)^2+(Lambda_f*W1+Ra*Is_rated)^2-Vs_rated^2;
f3=(Ls*W2*Is_rated)^2+(Vs_rated-Ra*Is_rated)^2-(Lambda_f*W2)^2;
W1=max(double(solve(f2)));
W2=max(double(solve(f3)));
Wmax=6000*2*pi/60*p/2;

%% Deriving Capability Curve

Resol=1000;

Wr=linspace(0,Wmax,Resol);
Is=linspace(Is_rated,Is_rated,Resol);
V_Xs=Ls*Wr.*Is;
V_Zs=(((Ls*Wr).^2+Ra^2).^0.5).*Is;

Ei=zeros(1,Resol);
Vs=zeros(1,Resol);

S1=find(abs(Wr-W1)==min(abs(Wr-W1)));
S2=find(abs(Wr-W2)==min(abs(Wr-W2)));


for k=1:Resol
    
    if k<=S1   
        Ei(k)=Lambda_f*Wr(k);
        Vs(k)=sqrt((Ei(k)+Ra*Is(k))^2+V_Xs(k)^2);

    elseif k>S1 && k<=S2
        Ei(k)=Lambda_f*Wr(k);
        Vs(k)=Vs(S1);

    else
        Vs(k)=Vs(S1);
        Ei(k)=sqrt((Vs(k)-Ra*Is(k))^2+V_Xs(k)^2);

    end

end

cos_delta=((Vs.^2+Ei.^2-V_Zs.^2)./(2*Ei.*Vs));

theta1=acos((Vs.^2+V_Zs.^2-Ei.^2)./(2*Vs.*V_Zs));
theta2=atan2(Ra,Ls*Wr);

pf=sin(theta1+theta2);

V_LtoL=sqrt(3)*Vs;
Wrm=Wr*2/p*60/2/pi;


Pmech=3*(Vs.*Ei.*(Ra*cos_delta+Ls*Wr.*sqrt(1-cos_delta.^2))-Ra*Ei.^2)./(Ra^2+(Ls*Wr).^2);
T=Pmech./(Wr*2/p);

%% Plot


hold on; grid on;
plot(Wrm,V_LtoL,Wrm,Is,Wrm,T,Wrm,Pmech/1000,Wrm,pf*100,'linewidth',2)
title('Capability Curve of Synchronous Machine');
legend('VLtoL[V]','Is[A]','Torque[Nm]','Power[kW]','pf[100]');
xlabel('Wrm[rpm]')
axis auto

