clear all;
format short eng;

%% Parameters


Prated=22e3;
p=4;
Vs_LtoL_rated=220;
Vs_rated=Vs_LtoL_rated/sqrt(3);
Is_rated=75;
Rs=0.044;
Rr=0.0252;
Lls=0.55e-3;
Llr=0.47e-3;
Lm=12.9e-3;
Jtot=0.122;
We_rated=60*2*pi;
We_max=1080*pi; % rad/sec
Wrm_max=We_max*60/2/pi*2/p; % r/min

%% Calculation of Ratings

resol=5000;
s_temp=linspace(0,1,resol);
Zs=j*Lls*We_rated+Rs;
Zr=Rr./s_temp+j*Llr*We_rated;
Zm=j*Lm*We_rated;
Ztot=Zs+1./(1./Zr+1./Zm);
Is=Vs_rated./Ztot;
s_rated=s_temp(find(abs(abs(Is)-Is_rated)==min(abs(abs(Is)-Is_rated))));

Zr=Rr/s_rated+j*Llr*We_rated;

Wsl_rated=s_rated*We_rated;
Ztot=Zs+1/(1/Zr+1/Zm);
Is_rated=Vs_rated/Ztot;
Ir_rated=Is_rated*Zm/(Zr+Zm);
Em_rated=Is_rated*1/(1/Zm+1/Zr);
Lambda_rated=abs(Em_rated/(We_rated));

%% Main Loop Variables

Resol=2000;

We=linspace(0,We_max,Resol);
Srated=find(abs(We-We_rated)==min(abs(We-We_rated)));

Wsl=zeros(1,Resol);
s=zeros(1,Resol);
Zs=zeros(1,Resol);
Zr=zeros(1,Resol);
Zm=zeros(1,Resol);
Is=zeros(1,Resol);
Vs=zeros(1,Resol);


%% Inner Loop Variables

resol=1000;

s_inner=zeros(1,resol);
is=zeros(1,resol);
te=zeros(1,resol);
smin=0;
smax=0.1;

%% Deriving Capability Curve

for k=1:Resol
    
    if k<=Srated
        Wsl(k)=Wsl_rated;
        s(k)=Wsl(k)/We(k);
        Zs(k)=j*Lls*We(k)+Rs;
        Zr(k)=Rr/s(k)+j*Llr*We(k);
        Zm(k)=j*Lm*We(k);
        Vs(k)=Lambda_rated*We(k)*(Zs(k)+1/(1/Zm(k)+1/Zr(k)))*(1/Zm(k)+1/Zr(k));
        Is(k)=Vs(k)/(Zs(k)+1/(1/Zm(k)+1/Zr(k)));

    elseif k>Srated
        
        % starting inner loop
        for l=1:resol
            s_inner(l)=smin+l/resol*(smax-smin);
            Zs_inner=j*Lls*We(k)+Rs;
            Zr_inner=Rr/s_inner(l)+j*Llr*We(k);
            Zm_inner=j*Lm*We(k);
            Ztot_inner=Zs_inner+1/(1/Zm_inner+1/Zr_inner);
            is(l)=Vs_rated/Ztot_inner;
            ir=is(l)*Zm_inner/(Zr_inner+Zm_inner);
            te(l)=1.5*p*Rr/(s_inner(l)*We(k))*abs(ir)^2;

        end
        % ending inner loop
        
        sc=s_inner(find(abs(abs(is)-abs(Is_rated))==min(abs(abs(is)-abs(Is_rated))))); %  ϴ  slip
        sp=s_inner(find(te==max(te)));
        s(k)=min([sc sp]);
        Zs(k)=j*Lls*We(k)+Rs;
        Zr(k)=Rr/s(k)+j*Llr*We(k);
        Zm(k)=j*Lm*We(k);
        Vs(k)=Vs_rated;
        Is(k)=Vs(k)/(Zs(k)+1/(1/Zm(k)+1/Zr(k)));
        Wsl(k)=We(k)*s(k);

    end

end

Wrm=(1-s).*We.*2/p*60/2/pi;
Ir=Is.*Zm./(Zr+Zm);
P=3*abs(Ir).^2.*(1-s)./(s).*Rr;
Te=P./((1-s).*We.*2/p);

%% PLOT

figure(1);
hold on;
grid on;
plot(We,abs(Wsl),'c','linewidth',2)
plot(We,abs(Vs),'b','linewidth',2)
plot(We,abs(Is),'r','linewidth',2)
plot(We,Te,'m','linewidth',2)
plot(We,P/1000,'k','linewidth',2)
title('Capability Curve of Induction Machine');
legend('Wsl[rad/s]','Vs[V]','Is[A]','Torque[Nm]','Power[kW]');
xlabel('We[rad/s]');
axis([0 We_max 0 150]);

%% CH2 12.1

figure(2);
plot(We,abs(Vs),'linewidth',2)
title('V/F Table');
xlabel('We[rad/s]');
ylabel('Vs[V]');
axis([0 360*pi 0 150]);
grid on;

%% CH2 12.2

figure(3);
Wsl_prob2=linspace(-10,10,Resol);
Te_prob2=3/2*p*Lambda_rated^2*Rr*Wsl_prob2./(Rr^2+(Llr*Wsl_prob2).^2);
plot(Te_prob2,Wsl_prob2,'linewidth',2)

title('Slip Angular Frequency According to the Torque');
xlabel('Te[N\cdotm]');
ylabel('Wsl[rad/s]]');
axis([-200 200 -10 10]);
grid on;

%% CH2 12.3

figure(4);
Wsl_prob3=linspace(0,9,Resol);
Is_prob3=Lambda_rated*(Wsl_prob3./(Rr+j*Llr*Wsl_prob3)+1/(j*Lm));
plot(abs(Is_prob3),Wsl_prob3,'linewidth',2)

title('Slip Angular Frequency According to the Stator Current');
xlabel('Is[Arms]');
ylabel('Wsl[rad/s]]');
axis([0 120 0 9]);
grid on;

