clear all;
format short eng;

%% Parameters

Prated=2.7e3; % rated output
Vs_rated_LtoL=220; % rated value of line to line voltage
Vs_rated=Vs_rated_LtoL/sqrt(3); % rated value of phase voltage
p=4; % number of poles
We_rated=60*2*pi; % rated supply frequency
Wrm=1810*2*pi/60*p/2;

Rs_pu=0.023;
Xls_pu=0.09;
Xm_pu=1.5;
Rr_pu=0.03;
Xlr_pu=0.11;

%% Converting Parameters from P.U. Values to Actual Values

Pb=Prated;
Vb=Vs_rated;
Ib=Prated/Vb/3;
Zb=Vb/Ib;
Wb=We_rated;

Rs=Rs_pu*Zb;
Xls=Xls_pu*Zb;
Xm=Xm_pu*Zb;
Rr=Rr_pu*Zb;
Xlr=Xlr_pu*Zb;

Lls=Xls/Wb;
Lm=Xm/Wb;
Llr=Xlr/Wb;

%% Calculating Active Power to the Machine

f=58; % applied frequency
We=f*2*pi;

s=(We-Wrm)/We;

Zs=j*Lls*We+Rs;
Zr=j*Llr*We+Rr/s;
Zm=j*Lm*We;
Ztot=Zs+1/(1/Zr+1/Zm);

Is=Vs_rated/Ztot;
Ir=Is*Zm/(Zm+Zr);

Pin=3*real(Vs_rated*conj(Is));
sprintf('The active power to the machine from the VVVF inverter is %fW.',Pin)






