clear all;
format short eng;
%% Problem 2-15 for moer accurate capability curve
%plot the capagility curve of the induction machine, whose parameters and
%limiting conditions are listed belows, in the format shown in Fig 2.77.

%% Parameter


Prated=185e+3;
Rs=0.014;
Rr=0.014;
p=4;
We_rated=60*2*pi;
Wr_rated=1773*2*pi/60*p/2;
Wrm_max=12500;
We_max=Wrm_max*2*pi/60*p/2;
Vs_rated=440/sqrt(3);
Lls=0.278e-3;
Llr=0.278e-3;
Lm=15e-3;

Wsl_rated=We_rated-Wr_rated;
s_rated=Wsl_rated/We_rated;

Zs=j*Lls*We_rated+Rs;
Zr=Rr/s_rated+j*Llr*We_rated;
Zm=j*Lm*We_rated;
Ztot=Zs+1/(1/Zr+1/Zm);
Is_rated=Vs_rated/Ztot;
Ir_rated=Is_rated*Zm/(Zr+Zm);
Em_rated=Is_rated*1/(1/Zr+1/Zm);
Lambda_rated=abs(Em_rated/(We_rated));

%% Main Loop 

Resol=1000; %

We=linspace(0,We_max,Resol);
Srated=find(abs(We-We_rated)==min(abs(We-We_rated)));

Wsl=zeros(1,Resol);
s=zeros(1,Resol);
Zs=zeros(1,Resol);
Zr=zeros(1,Resol);
Zm=zeros(1,Resol);
Is=zeros(1,Resol);
Vs=zeros(1,Resol);


%% Inner Loop 

resol=1000; 

s_inner=zeros(1,resol);
is=zeros(1,resol);
te=zeros(1,resol);
smin=0;
smax=0.1;

%% 

for k=1:Resol
    
    if k<=Srated
        Wsl(k)=Wsl_rated;
        s(k)=Wsl(k)/We(k);
        Zs(k)=j*Lls*We(k)+Rs;
        Zr(k)=Rr/s(k)+j*Llr*We(k);
        Zm(k)=j*Lm*We(k);
        Vs(k)=Lambda_rated*We(k)*(Zs(k)+1/(1/Zr(k)+1/Zm(k)))*(1/Zr(k)+1/Zm(k));
        Is(k)=Vs(k)/(Zs(k)+1/(1/Zr(k)+1/Zm(k)));

    elseif k>Srated
        
        for l=1:resol
            s_inner(l)=smin+l/resol*(smax-smin);
            Zs_inner=j*Lls*We(k)+Rs;
            Zr_inner=Rr/s_inner(l)+j*Llr*We(k);
            Zm_inner=j*Lm*We(k);
            Ztot_inner=Zs_inner+1/(1/Zr_inner+1/Zm_inner);
            is(l)=Vs_rated/Ztot_inner;
            ir=is(l)*Zm_inner/(Zr_inner+Zm_inner);
            te(l)=1.5*p*Rr/(s_inner(l)*We(k))*abs(ir)^2;

        end
        
        
        sc=s_inner(find(abs(abs(is)-abs(Is_rated))==min(abs(abs(is)-abs(Is_rated))))); %  ϴ  slip
        sp=s_inner(find(te==max(te))); 
        s(k)=min([sc sp]); 
        Zs(k)=1i*Lls*We(k)+Rs;
        Zr(k)=Rr/s(k)+1i*Llr*We(k);
        Zm(k)=1i*Lm*We(k);
        Vs(k)=Vs_rated;
        Is(k)=Vs(k)/(Zs(k)+1/(1/Zr(k)+1/Zm(k)));
        Wsl(k)=We(k)*s(k);

    end

end

Wrm=(1-s).*We.*2/p*60/2/pi;
Ir=Is.*Zm./(Zr+Zm);
P=3*abs(Ir).^2.*(1-s)./(s).*Rr;
T=P./((1-s).*We.*2/p);

%% PLOT

hold on;
grid on;
plot(Wrm,abs(Wsl),'c','linewidth',2)
plot(Wrm,abs(Vs),'b','linewidth',2)
plot(Wrm,abs(Is),'r','linewidth',2)
plot(Wrm,T,'m','linewidth',2)
plot(Wrm,P/1000,'k','linewidth',2)
title('Capability Curve of Induction Machine');
legend('Wsl[rad/s]','Vs[V]','Is[A]','Torque[Nm]','Power[kW]');
xlabel('Wrm[rpm]');
axis([0 Wrm_max 0 1000]);

