clear all;
format short eng;
%% Problem 2-16 
% The operating speed of a NEMA D-type induction machine, whose paramters
% are listed belows, is adjusted by controlling the terminal voltage of the
% machine. 
%
% The torque-speed curve of the load is given as TL=30*(Wrm/1800)^2, where
% Wrm stands for the speed of the machine in r/min.
% 
%(1) When the line-to-line voltage of the stator terminal in rms is 440V,
% find the operating speed in the steady state. Also find the efficiency of
% the machine at that operationg point.
%
%(2) When line-to-line voltage of the stator terminal in rms is reduced to
%220V, find the operating speed in the steady state. Also find the
%efficiency of the machine at that operationg point. 


%% Parameter

P_rate=5500;        %Rated power
Rs=0.69;
Rr=2.25;
P=4;                %Number of poles 
We_rate=60*2*pi;
Vs_phase=440/sqrt(3); %Rated voltage(line-to_line)
Lls=0.0059;
Llr=0.0059;
Lm=0.12;

Zs=Rs+1i*We_rate*Lls;
Zm=1i*We_rate*Lm;

%% Setting to find value
Wr_max=450;
step=2000;
Wr=zeros(1,step);
Wrpm=zeros(1,step);
slip=zeros(1,step);
Te1=zeros(1,step);
Te2=zeros(1,step);
Tl=zeros(1,step);
Ir1=zeros(1,step);
Ir2=zeros(1,step);
Is1=zeros(1,step);
Is2=zeros(1,step);
Zr=zeros(1,step);
Zeq=zeros(1,step);
TL=zeros(1,step);


for k=1:step
   Wr(k)=(k)/step*Wr_max;
   Wrpm(k)=Wr(k)/P*2*60/2/pi;
   slip(k)=(We_rate-Wr(k))/We_rate;
   Zr(k)=Rr/slip(k)+1i*We_rate*Llr;
   Zeq(k)=Zs+1/((1/Zm)+(1/Zr(k)));
   Is1(k)=Vs_phase/Zeq(k);
   Is2(k)=Vs_phase/2/Zeq(k);
   Ir1(k)=Vs_phase/Zeq(k)*Zm/(Zm+Zr(k));
   Ir2(k)=Vs_phase/2/Zeq(k)*Zm/(Zm+Zr(k));
   Te1(k)=3*P/2*Rr/slip(k)/We_rate*(abs(Ir1(k)))^2;
   Te2(k)=3*P/2*Rr/slip(k)/We_rate*(abs(Ir2(k)))^2;
   TL(k)=30*(Wrpm(k)/1800)^2;
end

figure(1);
plot(Wrpm,Te1,'b');
grid on;
hold on;
plot(Wrpm,Te2,'r');
plot(Wrpm,TL,'k');
title('Ex2-16 torque-speed curve with load torque');
xlabel('Wrm[rpm]');
ylabel('Te[N-m]');
legend('V_line=440','V_line=220','T_Load', 3);
ylim([0 100]);
xlim([0 2000]);
hold off;

%% After finding the crossing point from the plotted torque curve
Operating_Wrpm1=1680.375;
Operating_Wrpm2=1388.595;

Operating_Is1=Is1(max(find(Wrpm<Operating_Wrpm1)));
Operating_Is2=Is2(max(find(Wrpm<Operating_Wrpm2)));
Pin1=3*real(Vs_phase*conj(Operating_Is1));
Pin2=3*real(Vs_phase/2*conj(Operating_Is2));

Operating_Te1=Te1(max(find(Wrpm<Operating_Wrpm1)));
Operating_Te2=Te2(max(find(Wrpm<Operating_Wrpm2)));
Pout1=Operating_Te1*Operating_Wrpm1*2*pi/60;
Pout2=Operating_Te2*Operating_Wrpm2*2*pi/60;

efficiency1=Pout1/Pin1*100;
efficiency2=Pout2/Pin2*100;






