clear all; clc;

% Parameters given
motor = 2; % 1~4
if (motor == 1)
    Power = hp2watt(3);         % rated power
    wrm_rated = 1710;           % rpm
    P = 4;                      % Number of Pole
    Vll_rated = 220*sqrt(2);    % Rated voltage line to line
    w_rated = 2*pi*60;          % Hz, rated frequency
    Rs = 0.435;                 % Stator resistance
    Rr = 0.816;                 % Rotor resistance
    Lm = 26.13/w_rated;         % Mutual Inductance
    Lls = 0.754/w_rated;        % Stator transient inductance
    Llr = Lls;                  % Set rotor inductance
    
    J = 0.089;           % Mechanical load condition referenced summer lecture
    B = 0;
    
    simtime = 0.8;
end
if (motor == 2)
    Power = 22e3;         % rated power
    wrm_rated = 1765;           % rpm
    P = 4;                      % Number of Pole
    Vll_rated = 220*sqrt(2);    % Rated voltage line to line
    w_rated = 2*pi*60;               % Hz, rated frequency
    Rs = 0.044;                 % Stator resistance
    Rr = 0.0252;                 % Rotor resistance
    Lm = 12.9e-3;         % Mutual Inductance
    Lls = 0.55e-3;        % Stator transient inductance
    Llr = 0.47e-3;                  % Set rotor inductance
    
    J = 0.122;           % Mechanical load condition referenced summer lecture
    B = 0;
    
    simtime = 0.9;
end
if (motor == 3)
    Power = 185e3;         % rated power
    wrm_rated = 0;           % rpm
    P = 4;                      % Number of Pole
    Vll_rated = 220*sqrt(2);    % Rated voltage line to line
    w_rated = 2*pi*60;               % Hz, rated frequency
    Rs = 0.013;                 % Stator resistance
    Rr = 0.075;                 % Rotor resistance
    Lm = 12e-3;         % Mutual Inductance
    Lls = 0.1e-3;        % Stator transient inductance
    Llr = 0.1e-3;                  % Set rotor inductance
    
    J = 4;           % Mechanical load condition referenced summer lecture
    B = 0;
    
    simtime = 2;
end
if (motor == 4)
    Power = hp2watt(2250);         % rated power
    wrm_rated = 1786;           % rpm
    P = 4;                      % Number of Pole
    Vll_rated = 2300*sqrt(2);    % Rated voltage line to line
    w_rated = 2*pi*60;               % Hz, rated frequency
    Rs = 0.029;                 % Stator resistance
    Rr = 0.022;                 % Rotor resistance
    Lm = 13.04/w_rated;         % Mutual Inductance
    Lls = 0.226/w_rated;        % Stator transient inductance
    Llr = Lls;                  % Set rotor inductance
    
    J = 63.87;           % Mechanical load condition referenced summer lecture
    B = 0;
    
    simtime = 4;
end


Ls = Lls + Lm;  clear Lls;
Lr = Llr + Lm;  clear Llr;
sigma = 1 - Lm^2/(Ls*Lr);

Vph_rated = Vll_rated/sqrt(3);
wrm_rated = rpm2rps(wrm_rated); % rad/s

% Simulation Parameter

sim('Ch3_Num3_4_sim.mdl');

% Plotting

figure(1);
plot(time,AphaseVoltage);title('A phase Voltage');
xlabel('time[s]');ylabel('Voltage[V]')
grid;

figure(2);
plot(time,AphaseCurrent);title('A phase Current');
xlabel('time[s]');ylabel('Current[A]')
grid;

figure(3);
plot(time,Torque_s);title('Torque made by Induction Machine');
xlabel('time[s]');ylabel('Torque[N-m]')
grid;

figure(4);
plot(time,MachineSpeed);title('Speed of Machine');
xlabel('time[s]');ylabel('Speed[rpm]')
grid;

figure(5);
plot(MachineSpeed,Torque_s);title('Speed-Torque curve');
xlabel('Speed[rpm]');ylabel('Torque[N-m]')
grid;

figure(6);
plot(time,Vdqs);title('d-q Voltage');
xlabel('time[s]');ylabel('Voltge[V]')
grid;

figure(7);
plot(time,Idqs);title('d-q Current');
xlabel('time[s]');ylabel('Current[t]')
grid;

figure(8);
plot(time,Lam_dqss);title('d-q Stator Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(9);
plot(time,Lam_dqrs);title('d-q Rotor Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(10);
plot(time,Torque_s);title('Torque');
xlabel('time[s]');ylabel('Torque[Nm]')
grid;

figure(11);
plot(time,Power_s);title('Power');
xlabel('time[s]');ylabel('Power[W]')
grid;

figure(12);
plot(time,Vdqe);title('d-q Voltage');
xlabel('time[s]');ylabel('Voltge[V]')
grid;

figure(13);
plot(time,Idqe);title('d-q Current');
xlabel('time[s]');ylabel('Current[t]')
grid;

figure(14);
plot(time,Lam_dqse);title('d-q Stator Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(15);
plot(time,Lam_dqre);title('d-q Rotor Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(16);
plot(time,Torque_e);title('Torque');
xlabel('time[s]');ylabel('Torque[Nm]')
grid;

figure(17);
plot(time,Power_e);title('Power');
xlabel('time[s]');ylabel('Power[W]')
grid;

figure(18);
plot(time,Vdqr);title('d-q Voltage');
xlabel('time[s]');ylabel('Voltge[V]')
grid;

figure(19);
plot(time,Idqr);title('d-q Current');
xlabel('time[s]');ylabel('Current[t]')
grid;

figure(20);
plot(time,Lam_dqsr);title('d-q Stator Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(21);
plot(time,Lam_dqrr);title('d-q Rotor Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(22);
plot(time,Torque_r);title('Torque');
xlabel('time[s]');ylabel('Torque[Nm]')
grid;

figure(23);
plot(time,Power_r);title('Power');
xlabel('time[s]');ylabel('Power[W]')
grid;

figure(24);
plot(time,Vdqw);title('d-q Voltage');
xlabel('time[s]');ylabel('Voltge[V]')
grid;

figure(25);
plot(time,Idqw);title('d-q Current');
xlabel('time[s]');ylabel('Current[t]')
grid;

figure(26);
plot(time,Lam_dqsw);title('d-q Stator Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(27);
plot(time,Lam_dqrw);title('d-q Rotor Flux');
xlabel('time[s]');ylabel('Flux[Wb-t]')
grid;

figure(28);
plot(time,Torque_w);title('Torque');
xlabel('time[s]');ylabel('Torque[Nm]')
grid;

figure(29);
plot(time,Power_w);title('Power');
xlabel('time[s]');ylabel('Power[W]')
grid;