clear all; clc; close all;

% Problem 3.

% Parameter
Power = 3.08e3;     % 3.08 kW
Ra = 0.26;          % Armature resistance [Ohm]
La = 1.7e-3;        % Armature inductance [Henry]
Irated = 24.9;      % Rated armature current [A]
wrated = 3000;      % Rated speed [r/min]
Vrated = 139;       % Rated armature voltage [V]
Jmotor = 0.00252;   % Inertia of the rotor of the motor [kgm^2]
Jload = Jmotor;     % Inertia of the load
B = 0.005;          % friction coefficient [N-m/(rad/s)]
Vdc = 300;          % DC link voltage
Vlimit = 250;       % Voltage limit

% constant calculation of DC machine
wrated = rpm2rps(wrated);               % r/min -> rad/sec
ke = (Vrated - Ra*Irated)/wrated;       % back EMF constant
kt = Power/(Irated*wrated);             % torque constant
K = 0.5 * (ke + kt);                    % Average value to use

% PWM
fsw = 5e3;          % Switching Frequency
Tsw = 1/fsw;        % Switching Period
C = 2*Vdc/(Tsw/2);  % Carrier slope

% Controller Parameter
K_hat = 0.95*K;
La_hat = La;
Ra_hat = Ra;
wcc = 2*pi*1e3;
Kp = La_hat*wcc;
Ki = Ra_hat*wcc;

%% sub-problem (1) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% simulation A %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sim('problem4_3_1A_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(1-A) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(1-A) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(1-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(1-A) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(1-A) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

clear time; clear wrm;
clear ia;clear ia_ref;
clear Te;clear Te_ref;
clear Va_ref;clear Vc_ref;clear V;

% simulation B %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% anti-windup gain
Ka = 1/Kp;
sim('problem4_3_1B_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(1-B) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(1-B) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(1-B) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(1-B) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(1-B) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

clear time; clear wrm;
clear ia;clear ia_ref;
clear Te;clear Te_ref;
clear Va_ref;clear Vc_ref;clear V;
% end of sub-problem (1) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (2) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sampling parameter
fsamp = fsw;
Tsamp = Tsw;

% Butterworth low-pass filter
fc = 1e3;               % fc = fsw/5
wc = 2*pi*fc;
p1 = wc*exp(j*135*pi/180);
p2 = wc*exp(j*(-135)*pi/180);

% PI regulator
wcc = 2*pi*fsw/40;      % By table 4.1, Low pass filtering.
Kp = La_hat*wcc;
Ki = Ra_hat*wcc;
Ka = 1/Kp;

% simulation
sim('problem4_3_2_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(2) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(2) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(2) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(2) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(2) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

figure;hold on
plot(time,ia_ref,'b');plot(time,ia_fil,'r');
title('(2) Current');
axis([0.039 0.04 -20 20]);
xlabel('time[s]');ylabel('Current[A]');
legend('Current reference','filtered armature current');
grid;hold off

clear time;
clear Va_ref; clear Vc_ref; clear V;
clear ia; clear ia_ref; clear ia_fil;
clear Te; clear Te_ref;
clear wrm;
% end of sub-problem (2) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (3) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PI regulator
wcc = 2*pi*fsw/21;      % By table 4.1, Sampling at Peak.
Kp = La_hat*wcc;
Ki = Ra_hat*wcc;
Ka = 1/Kp;

% simulation
sim('problem4_3_3_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(3) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(3) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(3) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(3) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(3) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

figure;hold on
plot(time,ia_ref,'b');plot(time,ia_samp,'r');
title('(3) Current');
axis([0.039 0.04 -20 20]);
xlabel('time[s]');ylabel('Current[A]');
legend('Current reference','sampled armature current');
grid;hold off

clear time;
clear Va_ref; clear Vc_ref; clear V;
clear ia; clear ia_ref; clear ia_samp;
clear Te; clear Te_ref;
clear wrm;
% end of sub-problem (3) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (4) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PI regulator
wcc = 2*pi*fsw/10;      % By table 4.1, Double sampling.
Kp = La_hat*wcc;
Ki = Ra_hat*wcc;
Ka = 1/Kp;

% simulation
sim('problem4_3_4_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(4) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(4) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(4) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(4) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(4) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

figure;hold on
plot(time,ia_ref,'b');plot(time,ia_samp,'r');
title('(4) Current');
axis([0.039 0.04 -20 20]);
xlabel('time[s]');ylabel('Current[A]');
legend('Current reference','sampled armature current');
grid;hold off

clear time;
clear Va_ref; clear Vc_ref; clear V;
clear ia; clear ia_ref; clear ia_samp;
clear Te; clear Te_ref;
clear wrm;
% end of sub-problem (4) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (5) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PI regulator
La_hat = 0.9*La;
wcc = 2*pi*fsw/3.5;      % By table 4.1, Double sampling.
Kp = La_hat*wcc;
Ki = Ra_hat*wcc;
Ka = 1/Kp;

% simulation
sim('problem4_3_5_sim.mdl');

figure;hold on
plot(time,ia,'r');plot(time,ia_ref,'b');
title('(5) Current');
xlabel('time[s]');ylabel('Current[A]');
legend('Current','Current Reference');
grid;hold off

figure;hold on
plot(time,Te,'r');plot(time,Te_ref,'b');
title('(5) Torque');
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Torque','Torque Reference');
grid;hold off

figure;
plot(time,wrm);
title('(5) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

figure;
plot(time,Va_ref);
title('(5) Voltage Reference');
xlabel('time[s]');ylabel('Voltage[V]');
grid;

figure;hold on
plot(time,Vc_ref,'b');plot(time,V,'r');
title('(5) Voltage');axis([0.039 0.04 -300 300]);
xlabel('time[s]');ylabel('Voltage[V]');
legend('Limited voltage','Actual PWM voltage');
grid;hold off

figure;hold on
plot(time,ia_ref,'b');plot(time,ia_n,'r');plot(time,ia_n1,'k');
title('(5) Current');
axis([0.039 0.04 -20 20]);
xlabel('time[s]');ylabel('Current[A]');
legend('Current reference','ia[n]','ia[n+1]');
grid;hold off

clear time;
clear Va_ref; clear Vc_ref; clear V;
clear ia; clear ia_ref; clear ia_n; clear ia_n1;
clear Te; clear Te_ref;
clear wrm;
% end of sub-problem (5) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%