clear all; clc; close all;

% Problem 4.
% sub-problem selection
sub_problem = 12;        % 1~12

% Parameter
Power = 3.08e3;     % 3.08 kW
Ra = 0.26;          % Armature resistance [Ohm]
La = 1.7e-3;        % Armature inductance [Henry]
Irated = 24.9;      % Rated armature current [A]
wrated = 3000;      % Rated speed [r/min]
Vrated = 139;       % Rated armature voltage [V]
Jmotor = 0.00252;   % Inertia of the rotor of the motor [kgm^2]
Jload = Jmotor;     % Inertia of the load
J = Jmotor + Jload;
B = 0.005;          % friction coefficient [N-m/(rad/s)]
curr_lim = 75;      % Current limitation

% constant calculation of DC machine
wrated = rpm2rps(wrated);               % r/min -> rad/sec
ke = (Vrated - Ra*Irated)/wrated;       % back EMF constant
kt = Power/(Irated*wrated);             % torque constant
K = 0.5 * (ke + kt);                    % Average value to use

% PWM
fsw = 5e3;          % Switching Frequency
Tsw = 1/fsw;        % Switching Period

% Controller Parameter
K_hat = 0.95*K;
La_hat = La;
Ra_hat = Ra;
J_hat = J;
wcc = 2*pi*fsw/10;      % By table 4.1, Double sampling.

%% sub-problem (1) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 1)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% simulation
sim('problem4_4_1_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(1-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(1-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(1-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(1-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(1-C) Torque');
axis([0.065 0.08 -5 15]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(1-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(1-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (1) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (2) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 2)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Sampling parameter
Tsamp = 200e-6;

% simulation
sim('problem4_4_2_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(2-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(2-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(2-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(2-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(2-C) Torque');
axis([0.065 0.08 -5 15]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(2-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(2-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (2) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (3) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 3)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Sampling parameter
Tsamp = 2e-3;

% simulation
sim('problem4_4_2_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(3-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(3-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(3-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(3-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(3-C) Torque');
axis([0.065 0.08 -50 50]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(3-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(3-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (3) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (4) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 4)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% M method
Tsamp_m = .5e-3;
Tsamp = .5e-3;

% simulation
sim('problem4_4_4_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(4-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(4-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(4-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(4-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(4-C) Torque');
axis([0.065 0.08 -50 50]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(4-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(4-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (4) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (5) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 5)
% M/T method
Tsamp = 5e-4;

% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% simulation
sim('problem4_4_5_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(5-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(5-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(5-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(5-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(5-C) Torque');
axis([0.065 0.08 -40 40]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(5-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(5-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (5) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (6) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 6)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.004;

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots
% gain
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;

% simulation
sim('problem4_4_6_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(6-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(6-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(6-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(6-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(6-C) Torque');
axis([0.065 0.08 -5 15]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(6-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(6-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (6) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (7) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 7)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% Sampling (PWM)
Tsamp_ob = 100e-6;       % Observer sampling time
Tsamp = 5e-4;            % Speed regulator sampling time

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots

% gain
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;

% simulation
sim('problem4_4_7_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(7-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(7-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(7-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(7-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(7-C) Torque');
axis([0.065 0.08 -5 50]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(7-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(7-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (7) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (8) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 8)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% Sampling (PWM)
Tsamp_ob = 100e-6;       % Observer sampling time
Tsamp = .5e-3;            % Speed regulator sampling time

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots

% gain
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;

% simulation
sim('problem4_4_8_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(8-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(8-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(8-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(8-B) armature current reference');
axis([0.045 0.055 -150 150]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(8-C) Torque');
axis([0.065 0.08 -5 50]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(8-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(8-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (8) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (9) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 9)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% Sampling (PWM)
Tsamp_ob = 100e-6;       % Observer sampling time
Tsamp =.5e-3;            % Speed regulator sampling time

% acceleration feedback
Ka = J_hat;

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots

% gain
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;

% simulation
sim('problem4_4_9_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(9-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(9-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(9-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(9-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(9-C) Torque');
axis([0.065 0.08 -40 40]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(9-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(9-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (9) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (10) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 10)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 8192;         % Pulse per revolution
noise_mag = 0.04;

% Sampling (PWM)
Tsamp_ob = 100e-6;       % Observer sampling time
Tsamp = .5e-3;            % Speed regulator sampling time

% acceleration feedback
Ka = J_hat;

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Speed Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots

% gain for speed observer
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% Acc Observer Parameter
woba = 2*pi*50;
roota = -woba;       % root of characteristic equation, set as triple roots
% gain for acc. observer
L1a = -3*roota-B_hat/J_hat;
L2a = 3*roota^2-B_hat/J_hat*L1a;
L3a = roota^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;

% simulation
sim('problem4_4_10_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(10-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(10-A) armature current reference');
axis([0 0.09 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(10-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(10-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(10-C) Torque');
axis([0.065 0.08 -40 40]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(10-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(10-C) armature current reference');
axis([0.065 0.08 -100 200]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (10) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (11) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 11)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 2^22;         % Pulse per revolution
noise_mag = 0.04;

% M method
Tsamp_m = 100e-6;
Tsamp = 0.1e-3;

% simulation
sim('problem4_4_4_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(11-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(11-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(11-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(11-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(11-C) Torque');
axis([0.065 0.08 -5 20]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(11-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(11-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (11) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% sub-problem (12) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(sub_problem == 12)
% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2
Ksa = 1/Ksp;

% Encoder
ppr = 2^22;         % Pulse per revolution
noise_mag = 0.04;

% Sampling (PWM)
Tsamp_ob = 100e-6;       % Observer sampling time
Tsamp = 100e-6;          % Speed regulator sampling time

% acceleration feedback
Ka = J_hat;

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Observer Parameter
wob = 2*pi*500;
root = -wob;       % root of characteristic equation, set as triple roots

% Parameter
B_hat = 0.2*B;
J_hat = 0.7*J;

% Speed Observer Parameter
wob = 2*pi*200;
root = -wob;       % root of characteristic equation, set as triple roots

% gain for speed observer
L1 = -3*root-B_hat/J_hat;
L2 = 3*root^2-B_hat/J_hat*L1;
L3 = root^3*J_hat;

% Acc Observer Parameter
woba = 2*pi*500;
roota = -woba;       % root of characteristic equation, set as triple roots
% gain for acc. observer
L1a = -3*roota-B_hat/J_hat;
L2a = 3*roota^2-B_hat/J_hat*L1a;
L3a = roota^3*J_hat;

% % root of characteristic equation, set as butterworth roots
% b1 = wob*exp(j*2/3*pi);
% b2 = wob*exp(-j*2/3*pi);
% b3 = -wob;
% % gain
% L1 = -3*(b1+b2+b3)-B_hat/J_hat;
% L2 = (b1*b2+b2*b3+b3*b1)-B_hat/J_hat*L1;
% L3 = b1*b2*b3*J_hat;
% simulation

sim('problem4_4_10_sim.mdl');

figure;
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(12-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);plot(time,ia_ref);
title('(12-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(12-B) Speed');
axis([0.045 0.055 150 250]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(12-B) armature current reference');
axis([0.045 0.055 -100 100]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure;
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(12-C) Torque');
axis([0.065 0.08 -5 15]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(12-C) Speed');
axis([0.065 0.08 150 250]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(12-C) armature current reference');
axis([0.065 0.08 -100 100]);
xlabel('time[s]');ylabel('Current[A]');
grid;

clear time;
clear wrm;clear wrm_ref;
clear ia_ref;
clear Te;clear TL;
end
% end of sub-problem (12) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%