clear all; clc; close all;

% Problem 5.

% Parameter
Power = 3.08e3;     % 3.08 kW
Ra = 0.26;          % Armature resistance [Ohm]
La = 1.7e-3;        % Armature inductance [Henry]
Irated = 24.9;      % Rated armature current [A]
wrated = 3000;      % Rated speed [r/min]
Vrated = 139;       % Rated armature voltage [V]
Jmotor = 0.00252;   % Inertia of the rotor of the motor [kgm^2]
Jload = Jmotor;     % Inertia of the load
J = Jmotor + Jload;
B = 0.005;          % friction coefficient [N-m/(rad/s)]
curr_lim = 75;      % Current limitation

% constant calculation of DC machine
wrated = rpm2rps(wrated);               % r/min -> rad/sec
ke = (Vrated - Ra*Irated)/wrated;       % back EMF constant
kt = Power/(Irated*wrated);             % torque constant
K = 0.5 * (ke + kt);                    % Average value to use

% PWM
fsw = 5e3;          % Switching Frequency
Tsw = 1/fsw;        % Switching Period

% Controller Parameter
K_hat = 0.95*K;
La_hat = La;
Ra_hat = Ra;
J_hat = J;
wcc = 2*pi*fsw/10;      % By table 4.1, Double sampling.

% PI regulator for Speed controller
fsc = 200;          % Bandwidth of speed controller [Hz]
wsc = 2*pi*fsc;     % Bandwidth of speed controller [rad/s]
Ksp = J_hat*wsc/K_hat;
Ksi = Ksp*wsc/5;    % Dampling coefficient zeta = sqrt(5)/2

% IP regulator for Speed controller
fsc_ip = 200*(2*exp(1)*.68979);      % Bandwidth of speed controller [Hz]
% fsc_ip = 200*(2*exp(1));
wsc_ip = 2*pi*fsc_ip;                % Bandwidth of speed controller [rad/s]
Ksp_ip = J_hat*wsc_ip/K_hat;
Ksi_ip = Ksp_ip*wsc_ip/5;            % Dampling coefficient zeta = sqrt(5)/2

% simulation
sim('problem4_5_sim.mdl');


figure(1);
subplot(2,1,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(1-A) Speed');
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(2,1,2);
plot(time,ia_ref);
title('(1-A) armature current reference');
xlabel('time[s]');ylabel('Current[A]');
grid;

figure(2);
subplot(1,2,1);hold on
plot(time,wrm,'r');plot(time,wrm_ref,'b');
title('(1-B) Speed');
axis([0.045 0.055 175 225]);axis square;
xlabel('time[s]');ylabel('Speed[r/min]');
legend('Speed','Speed Reference');
grid;hold off

subplot(1,2,2);
plot(time,ia_ref);
title('(1-B) armature current reference');
axis([0.045 0.055 -30 30]);axis square;
xlabel('time[s]');ylabel('Current[A]');
grid;

figure(3);
subplot(3,1,1);hold on
plot(time,Te,'b');plot(time,TL,'r');
title('(1-C) Torque');
axis([0.065 0.08 -2 20]);
xlabel('time[s]');ylabel('Torque[N-m]');
legend('Te','TL');
grid;hold off

subplot(3,1,2);
plot(time,wrm);
title('(1-C) Speed');
axis([0.065 0.08 190 205]);
xlabel('time[s]');ylabel('Speed[r/min]');
grid;

subplot(3,1,3);
plot(time,ia_ref);
title('(1-C) armature current reference');
axis([0.065 0.08 -10 50]);
xlabel('time[s]');ylabel('Current[A]');
grid;

%clear time;
%clear wrm;clear wrm_ref;
%clear ia_ref;
%clear Te;clear TL;