clear all;
clc;

V_LL_rms_rated = 208;
I_rated = 11.8;
P_rated = 5*746;
Pole = 4;
PP = Pole/2;
rpm2rad= 2*pi/60;

R = 0.423;
L= 4.76e-3;
LamPM = 0.422;

J = 0.03;
B = 0.04;

wrm_const = 1200;
wrm_const_rad = wrm_const*rpm2rad;
t_a = 0.1;
dwdt_rpm = wrm_const/t_a;
dwdt_rad = wrm_const_rad/t_a;

t = 0:0.0001:0.25;

for i = 1:1:length(t),
    if t(i) >= 0.1
        wrm_rpm(i) = wrm_const;
        wrm(i) = wrm_rpm(i)*rpm2rad;
        Te(i) = B*wrm(i);
        iq(i) = Te(i)/(1.5*PP*LamPM);
        wr(i) = wrm(i)*PP;
        Theta(i) = wr(i)*(t(i)-0.1) + dwdt_rad*PP/2*0.01 ; % Theta initial value at t = 0.1
        ia(i) = -iq(i)*sin( Theta(i) );  
    else
        wrm_rpm(i) = dwdt_rpm*t(i);
        wrm(i) = wrm_rpm(i)*rpm2rad;
        Te(i) = J*dwdt_rad + B*wrm(i);
        iq(i) = Te(i)/(1.5*PP*LamPM);
        wr(i) = wrm(i)*PP;
        Theta(i) = wr(i)*t(i)/2;
        ia(i) = -iq(i)*sin( Theta(i) ); %  Theta = integ(wr)dt = integ(C*t)dt = (C*t^2)/2 = wr*t/2
    end
end


%%
figure(1)
hold on;
subplot(2,1,1), plot(t,wrm_rpm, 'LineWidth', 1.5)
grid on;
legend('w_{rm} [r/min]')
ylabel('w_{rm} [r/min]')
xlabel('Time [sec]')
subplot(2,1,2), plot(t, Te, 'LineWidth', 1.5)
legend('T_{e} [Nm]')
ylabel('T_{e} [Nm]')
xlabel('Time [sec]')
grid on;
hold off;

figure(2)
hold on;
plot(t, ia, 'LineWidth', 1.5);
grid on;
legend('i_{a} [A]')
ylabel('i_{a} [A]')
xlabel('Time [sec]')

figure(3)
hold on;
plot(t, Theta, 'LineWidth', 1.5);
grid on;
legend('Theta [rad]')
ylabel('Theta [rad]')
xlabel('Time [sec]')
