clear all;
clc;

Pole = 8;
PP = Pole/2;

rpm2rad = 2*pi/60;

LamPM = 180*sqrt(2)/sqrt(3)/(1800*rpm2rad*PP);

J = 0.01;
B = 0.1;

wrm_const = 1200*rpm2rad;
ta = 0.1;

dwrmdt = wrm_const/ta;

t = 0:0.0001:0.25;


for i = 1:1:length(t),
    if t(i) >= 0.1
        wrm(i) = wrm_const;
        Te(i) = B*wrm(i);
        iq(i) = Te(i)/(1.5*PP*LamPM);
        id(i) = 0;
        wr(i) = wrm(i)*PP;
        Theta(i) = wr(i)*(t(i)-0.1) + dwrmdt*PP/2*0.01 ; % Theta initial value at t = 0.1
        ia(i) = -sqrt(iq(i)^2+id(i)^2)*sin( Theta(i) );
    else
        wrm(i) = dwrmdt*t(i);
        Te(i) = J*dwrmdt + B*wrm(i);
        iq(i) = Te(i)/(1.5*PP*LamPM);
        id(i) = 0;
        wr(i) = wrm(i)*PP;
        Theta(i) = wr(i)*t(i)/2;
        ia(i) = -sqrt(iq(i)^2+id(i)^2)*sin( Theta(i) ); %  Theta = integ(wr)dt = integ(C*t)dt = (C*t^2)/2 = wr*t/2
    end
end

%%
figure(1)
hold on;
plot(t, Te, 'LineWidth', 1.5)
legend('T_{e} [Nm]')
ylabel('T_{e} [Nm]')
xlabel('Time [sec]')
axis([0 0.25 0 30])
grid on;
hold off;

figure(2)
hold on;
plot(t, id, 'LineWidth', 1.5);
plot(t, iq,'r', 'LineWidth', 1.5);
axis([0 0.25 -5 30])
grid on;
legend('i_{ds}^r [A]', 'i_{qs}^r [A]')
ylabel('current [A]')
xlabel('Time [sec]')

figure(3)
hold on;
plot(t, Theta, 'LineWidth', 1.5);
grid on;
legend('Theta [rad]')
ylabel('angle [rad]')
xlabel('Time [sec]')

figure(4)
hold on;
plot(t, ia, 'LineWidth', 1.5);
grid on;
legend('i_{a} [A]')
ylabel('i_{a} [A]')
xlabel('Time [sec]')
